@@ -419,12 +419,7 @@ class VirtualService(HttpClient, KempBaseObjectModel):
 
     def create_real_server(self, ip, port=80):
         """RealServer factory with pre-configured LoadMaster connection."""
-        loadmaster_virt_service_info = self._get_base_parameters()
-        loadmaster_virt_service_info.vs = self.vs
-        loadmaster_virt_service_info.port = self.port
-        loadmaster_virt_service_info.prot = self.prot
-        rs = RealServer(loadmaster_virt_service_info, ip, port)
-        return rs
+        return RealServer(self.get_virtual_service_info, ip, port)
 
     def get_real_server(self, index=None, address=None, port=None,
                         protocol=None, real_server_address=None,
@@ -514,8 +509,21 @@ class RealServer(HttpClient, KempBaseObjectModel):
             response = self._get("/addrs", self._get_base_parameters())
         else:
             response = self._get("/modrs", self.to_api_dict())
-        return send_response(response)
+        if is_successful(response):
+            response = self._get("/showrs", self._get_base_parameters())
+            data = get_data(response)
+            rs_data = data["Rs"]
+            self.populate_real_server_attributes(rs_data)
+        else:
+            raise KempTechApiException(get_error_msg(response))
 
     def delete(self):
         response = self._get("/delrs", self._get_base_parameters())
         return send_response(response)
+
+    def populate_real_server_attributes(self, rs_data):
+        self.status = rs_data.get('Status', None)
+        self.forward = rs_data.get('Forward', None)
+        self.enable = rs_data.get('Enable', None)
+        self.weight = rs_data.get('Weight', None)
+        self.limit = rs_data.get('Limit', None)
